@@ -19,14 +19,17 @@ lib = None
 
 try:
     import ecmwflibs
+
     lib = ecmwflibs.find("eccodes")
 except ModuleNotFoundError:
     lib = ctypes.util.find_library("eccodes")
 
 
 if lib is None:
-    for lib in ('/opt/ecmwf/eccodes/lib/libeccodes.so',
-                '/usr/local/lib/libeccodes.dylib'):
+    for lib in (
+        "/opt/ecmwf/eccodes/lib/libeccodes.so",
+        "/usr/local/lib/libeccodes.dylib",
+    ):
         if os.path.exists(lib):
             break
 
@@ -94,6 +97,7 @@ if sys.version_info[0] > 2:
     char_to_string = _char_to_string
     string_to_char = _string_to_char
 else:
+
     def convert_strings(x):
         return x
 
@@ -147,7 +151,6 @@ c_size_t_p = c_uint_p
 
 ####################################################################
 def checked_error_in_last_paramater(fn):
-
     def wrapped(*args):
         err = c_int(0)
         err_p = ctypes.cast(ctypes.addressof(err), c_int_p)
@@ -163,7 +166,6 @@ def checked_error_in_last_paramater(fn):
 
 
 def checked_return_code(fn):
-
     def wrapped(*args):
         err = fn(*args)
         if err:
@@ -174,8 +176,8 @@ def checked_return_code(fn):
 
 ####################################################################
 
-def return_type(fn, ctype):
 
+def return_type(fn, ctype):
     def wrapped(*args):
         result = ctype()
         result_p = ctypes.cast(ctypes.addressof(result), ctypes.POINTER(ctype))
@@ -186,6 +188,7 @@ def return_type(fn, ctype):
 
     return wrapped
 
+
 ####################################################################
 
 
@@ -203,7 +206,7 @@ grib_handle_new_from_message_copy.argtypes = (grib_context_p, c_void_p, c_size_t
 
 grib_handle_delete = dll.grib_handle_delete
 grib_handle_delete.restype = None
-grib_handle_delete.argtypes = (grib_handle_p, )
+grib_handle_delete.argtypes = (grib_handle_p,)
 
 ####################################################################
 
@@ -218,7 +221,7 @@ GRIB_KEYS_ITERATOR_ALL_KEYS = 0
 
 grib_keys_iterator_delete = dll.grib_keys_iterator_delete
 grib_keys_iterator_delete.restype = None
-grib_keys_iterator_delete.argtypes = (grib_keys_iterator_p, )
+grib_keys_iterator_delete.argtypes = (grib_keys_iterator_p,)
 
 ####################################################################
 grib_keys_iterator_next = dll.grib_keys_iterator_next
@@ -232,7 +235,11 @@ grib_keys_iterator_get_name = convert_strings(grib_keys_iterator_get_name)
 ####################################################################
 _grib_keys_iterator_get_string = dll.grib_keys_iterator_get_string
 _grib_keys_iterator_get_string.restype = c_int
-_grib_keys_iterator_get_string.argtypes = (grib_keys_iterator_p, c_char_p, c_size_t_p,)
+_grib_keys_iterator_get_string.argtypes = (
+    grib_keys_iterator_p,
+    c_char_p,
+    c_size_t_p,
+)
 
 _grib_keys_iterator_get_string = checked_return_code(_grib_keys_iterator_get_string)
 
@@ -259,6 +266,7 @@ def grib_iterate(handle, namespace):
 def grib_get_keys_values(handle, namespace):
     return dict(grib_iterate(handle, namespace))
 
+
 ####################################################################
 
 
@@ -322,6 +330,7 @@ _grib_get_long_array = checked_return_code(_grib_get_long_array)
 
 ####################################################################
 
+
 def grib_get_bytes(handle, name):
     raise Exception("Not implemented")
 
@@ -339,7 +348,7 @@ grib_get_native_type = return_type(grib_get_native_type, c_int)
 
 grib_get_error_message = dll.grib_get_error_message
 grib_get_error_message.restype = c_char_p
-grib_get_error_message.argtypes = (c_int, )
+grib_get_error_message.argtypes = (c_int,)
 grib_get_error_message = convert_strings(grib_get_error_message)
 
 ####################################################################
@@ -362,8 +371,8 @@ def grib_get_gaussian_latitudes(N):
 
 ####################################################################
 
-class GribError(Exception):
 
+class GribError(Exception):
     def __init__(self, err):
         super(GribError, self).__init__("%s (%s)" % (grib_get_error_message(err), err))
         self.err = err
@@ -374,15 +383,18 @@ grib_handle_new_from_file = checked_error_in_last_paramater(grib_handle_new_from
 
 ####################################################################
 grib_handle_new_from_message_copy = partial(grib_handle_new_from_message_copy, None)
-grib_handle_new_from_message_copy = checked_error_in_last_paramater(grib_handle_new_from_message_copy)
+grib_handle_new_from_message_copy = checked_error_in_last_paramater(
+    grib_handle_new_from_message_copy
+)
 
 ####################################################################
-TYPE_GETTERS = (None,
-                grib_get_long,
-                grib_get_double,
-                grib_get_string,
-                grib_get_bytes,
-                )
+TYPE_GETTERS = (
+    None,
+    grib_get_long,
+    grib_get_double,
+    grib_get_string,
+    grib_get_bytes,
+)
 
 
 def grib_get(handle, name):
@@ -438,9 +450,8 @@ fseek.restype = c_int
 
 
 class CFile(object):
-
     def __init__(self, path):
-        self.f = fopen(path, 'rb')
+        self.f = fopen(path, "rb")
         if not self.f:
             raise Exception("Cannot open %s" % (path,))
 
@@ -466,9 +477,8 @@ class CFile(object):
 
 
 class CFile2(object):
-
     def __init__(self, path):
-        self.f = open(path, 'rb')
+        self.f = open(path, "rb")
         if not self.f:
             raise Exception("Cannot open %s" % (path,))
         self.as_FILE = ctypes.pythonapi.PyFile_AsFile
