@@ -14,6 +14,7 @@ import json
 from climetlab.core.caching import temp_file
 from .base import FileSource, APIKeyPrompt
 
+
 class MARSAPI(APIKeyPrompt):
 
     text_message = """
@@ -73,12 +74,11 @@ def service(name):
 
 
 class MARSRetriever(FileSource):
-
     def __init__(self, **req):
-        self.path = temp_file('MARSRetriever', req)
+        self.path = temp_file("MARSRetriever", req)
         if not os.path.exists(self.path):
-            service('mars').execute(req, self.path + '.tmp')
-            os.rename(self.path + '.tmp', self.path)
+            service("mars").execute(req, self.path + ".tmp")
+            os.rename(self.path + ".tmp", self.path)
 
 
 source = MARSRetriever
