@@ -15,29 +15,30 @@ from tqdm import tqdm
 import zipfile
 import xarray as xr
 
-class ZipUrl(DataSource):
 
+class ZipUrl(DataSource):
     def __init__(self, url):
         self.path = temp_file("ZipUrl", url)
 
-        if not os.path.exists(self.path + '.d'):
-            if not os.path.exists(self.path + '.zip'):
+        if not os.path.exists(self.path + ".d"):
+            if not os.path.exists(self.path + ".zip"):
                 print("Downloading", url)
                 r = requests.head(url)
                 r.raise_for_status()
-                size = int(r.headers['content-length'])
+                size = int(r.headers["content-length"])
 
                 r = requests.get(url, stream=True)
                 r.raise_for_status()
                 total = 0
-                mode = 'wb'
-                with tqdm(total=size,
-                          unit_scale=True,
-                          unit_divisor=1024,
-                          unit='B',
-                          disable=False,
-                          leave=False,
-                          ) as pbar:
+                mode = "wb"
+                with tqdm(
+                    total=size,
+                    unit_scale=True,
+                    unit_divisor=1024,
+                    unit="B",
+                    disable=False,
+                    leave=False,
+                ) as pbar:
                     pbar.update(total)
                     with open(self.path, mode) as f:
                         for chunk in r.iter_content(chunk_size=1024):
@@ -45,22 +46,26 @@ class ZipUrl(DataSource):
                                 f.write(chunk)
                                 total += len(chunk)
                                 pbar.update(len(chunk))
-                os.rename(self.path, self.path + '.zip')
+                os.rename(self.path, self.path + ".zip")
             print("Unzipping...")
-            if not os.path.exists(self.path + '.tmp'):
-                os.mkdir(self.path + '.tmp')
+            if not os.path.exists(self.path + ".tmp"):
+                os.mkdir(self.path + ".tmp")
 
-            with zipfile.ZipFile(self.path + '.zip', "r") as zip_file:
-                for file in tqdm(iterable=zip_file.namelist(),
-                                 leave=False,
-                                 total=len(zip_file.namelist())):
-                    zip_file.extract(member=file, path=self.path + '.tmp')
+            with zipfile.ZipFile(self.path + ".zip", "r") as zip_file:
+                for file in tqdm(
+                    iterable=zip_file.namelist(),
+                    leave=False,
+                    total=len(zip_file.namelist()),
+                ):
+                    zip_file.extract(member=file, path=self.path + ".tmp")
 
             print("Done...")
-            os.rename(self.path + '.tmp', self.path + '.d')
-            os.unlink(self.path + '.zip')
+            os.rename(self.path + ".tmp", self.path + ".d")
+            os.unlink(self.path + ".zip")
 
-        self._xarray = xr.open_mfdataset(self.path + '.d/*.nc', combine='by_coords')  # nested
+        self._xarray = xr.open_mfdataset(
+            self.path + ".d/*.nc", combine="by_coords"
+        )  # nested
 
     def to_xarray(self):
         return self._xarray
